@@ -27,7 +27,7 @@ option month     => (is => 'ro', isa => Str, format => 's', doc => 'Month number
 option year      => (is => 'ro', isa => Int, format => 'i', doc => 'Year number (3/4 digits)');
 option gregorian => (is => 'ro', isa => Str, format => 's', doc => 'Gregorian date (YYYY-MM-DD)');
 option julian    => (is => 'ro', isa => Str, format => 'i', doc => 'Julian date');
-option name      => (is => 'ro', isa => Str, format => 's', required => 1, doc => 'Calendar name e.g. Bahai,Gregorian,Hijri,Persian,Saka.');
+option name      => (is => 'ro', isa => Str, format => 's', doc => "Calendar name e.g. Bahai,Gregorian,Hijri,Persian,Saka.\n\tDefault is Gregorian.");
 option 'as_svg'  => (is => 'ro', doc => 'Generate calendar in SVG format');
 option 'list_month_names' => (is => 'ro', doc => 'List calendar month names');
 
